@@ -1,4 +1,4 @@
-__all__ = ('WalletPoint',)
+__all__ = ('WalletPoint', 'WalletObjectPoint')
 
 from expressmoney.api import *
 
